==> u_team_core-fabric-1.20.1-5.1.4.382-multiloader_testsources.jar: info/u_team/u_team_test/test_multiloader/init/TestMultiLoaderCreativeTabs.java <==
package info.u_team.u_team_test.test_multiloader.init;

import java.util.stream.Stream;
import net.minecraft.class_1761;
import net.minecraft.class_1761.class_7705;
import net.minecraft.class_1772;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1844;
import net.minecraft.class_1889;
import info.u_team.u_team_core.api.registry.CreativeModeTabRegister;
import info.u_team.u_team_core.api.registry.RegistryEntry;
import info.u_team.u_team_test.test_multiloader.TestMultiLoaderReference;

public class TestMultiLoaderCreativeTabs {
	
	public static final CreativeModeTabRegister CREATIVE_TABS = CreativeModeTabRegister.create(TestMultiLoaderReference.MODID);
	
	public static final RegistryEntry<class_1761> TEST = CREATIVE_TABS.register("test_tab", builder -> {
		builder.method_47320(() -> new class_1799(TestMultiLoaderBlocks.TEST.get()));
		builder.method_47317((parameters, output) -> {
			TestMultiLoaderBlocks.BLOCKS.itemIterable().forEach(item -> {
				output.method_45421(item);
			});
			TestMultiLoaderItems.ITEMS.entryIterable().forEach(item -> {
				output.method_45421(item);
			});
			Stream.of(class_1802.field_8574, class_1802.field_8436, class_1802.field_8150, class_1802.field_8087).forEach(item -> {
				TestMultiLoaderPotions.POTIONS.entryIterable().forEach(potion -> {
					output.method_45417(class_1844.method_8061(new class_1799(item), potion), class_7705.field_40192);
				});
			});
			output.method_45417(class_1772.method_7808(new class_1889(TestMultiLoaderEnchantments.TEST.get(), 1)), class_7705.field_40192);
		});
	});
	
	static void register() {
		CREATIVE_TABS.register();
	}
	
}

==> u_team_core-fabric-1.21.1-5.6.2.364-multiloader_testsources.jar: info/u_team/u_team_test/test_multiloader/init/TestMultiLoaderCreativeTabs.java <==
package info.u_team.u_team_test.test_multiloader.init;

import java.util.stream.Stream;
import net.minecraft.class_1761;
import net.minecraft.class_1761.class_7705;
import net.minecraft.class_1772;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1844;
import net.minecraft.class_1889;
import net.minecraft.class_7924;
import info.u_team.u_team_core.api.registry.CreativeModeTabRegister;
import info.u_team.u_team_core.api.registry.RegistryEntry;
import info.u_team.u_team_test.test_multiloader.TestMultiLoaderReference;

public class TestMultiLoaderCreativeTabs {
	
	public static final CreativeModeTabRegister CREATIVE_TABS = CreativeModeTabRegister.create(TestMultiLoaderReference.MODID);
	
	public static final RegistryEntry<class_1761> TEST = CREATIVE_TABS.register("test_tab", builder -> {
		builder.method_47320(() -> new class_1799(TestMultiLoaderBlocks.TEST.get()));
		builder.method_47317((parameters, output) -> {
			TestMultiLoaderBlocks.BLOCKS.itemIterable().forEach(item -> {
				output.method_45421(item);
			});
			TestMultiLoaderItems.ITEMS.entryIterable().forEach(item -> {
				output.method_45421(item);
			});
			Stream.of(class_1802.field_8574, class_1802.field_8436, class_1802.field_8150, class_1802.field_8087).forEach(item -> {
				TestMultiLoaderPotions.POTIONS.forEach(potion -> {
					output.method_45417(class_1844.method_57400(item, potion.getHolder()), class_7705.field_40192);
				});
			});
			output.method_45417(class_1772.method_7808(new class_1889(parameters.comp_1253().method_46762(class_7924.field_41265).method_46747(TestMultiLoaderEnchantments.TEST), 1)), class_7705.field_40192);
		});
	});
	
	static void register() {
		CREATIVE_TABS.register();
	}
	
}
